@@ -8,10 +8,6 @@ app = Flask(__name__)
 class web():
   def __init__(self, title: str="Hello world!"):
     self.site_title = title
-
-
-  def start(self):
-    title = self.site_title
     @app.route("/")
     def main(self):
       return f"""
@@ -19,4 +15,7 @@ class web():
 <html> 
 <head><title>{title}</title></head>  
 </html>
-"""
\ No newline at end of file
+"""
+
+  def start(self):
+    app.run(host="0.0.0.0", port=8080)
\ No newline at end of file
